==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { ColumnSeriesDescription } from "./ColumnSeriesDescription";
/**
 * @hidden
 */
export let ColumnSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnSeriesDescriptionMetadata.a == null) {
                ColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnSeriesDescriptionMetadata.c(ColumnSeriesDescriptionMetadata.a);
            }
            if (a.j(ColumnSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
            a.item("ConsolidatedColumnVerticalPosition", "ExportedType:string:ConsolidatedItemsPosition");
            a.item("ConsolidatedColumnVerticalPosition@names", "Minimum;Maximum;Median;RelativeMinimum;RelativeMaximum");
        }
        static d(a) {
            ColumnSeriesDescriptionMetadata.b(a);
            a.aa("ColumnSeries", () => new ColumnSeriesDescription());
            a.z("ColumnSeries", ColumnSeriesDescriptionMetadata.a);
        }
    }
    ColumnSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnSeriesDescriptionMetadata, 'ColumnSeriesDescriptionMetadata');
    ColumnSeriesDescriptionMetadata.a = null;
    return ColumnSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { ColumnSeriesDescription } from "./ColumnSeriesDescription";
/**
 * @hidden
 */
export let ColumnSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnSeriesDescriptionMetadata.a == null) {
                ColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnSeriesDescriptionMetadata.c(ColumnSeriesDescriptionMetadata.a);
            }
            if (a.k(ColumnSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
            a.item("ConsolidatedColumnVerticalPosition", "ExportedType:string:ConsolidatedItemsPosition");
            a.item("ConsolidatedColumnVerticalPosition@names", "Minimum;Maximum;Median;RelativeMinimum;RelativeMaximum");
        }
        static d(a) {
            ColumnSeriesDescriptionMetadata.b(a);
            a.ac("ColumnSeries", () => new ColumnSeriesDescription());
            a.ab("ColumnSeries", ColumnSeriesDescriptionMetadata.a);
        }
    }
    ColumnSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnSeriesDescriptionMetadata, 'ColumnSeriesDescriptionMetadata');
    ColumnSeriesDescriptionMetadata.a = null;
    return ColumnSeriesDescriptionMetadata;
})();
